
clear all
capture log close
set mem 3g
set matsize 5000
set maxvar 10000
set more off

cd "F:\Work\OlmoFelix\Mobility\workfiles\"

*******************************************************************************************************
*	EFFECTS OF MOBILITY IN THE NEIGHBOURHOOD - Steve Gibbons, Olmo Silva, Felix Weinhardt
*	This do file uses one cohort and only three years/two mobility events from the LSYPE
*	We focus on assessing the impact of mobility on pupils' questions on friends
*	We estimate separately the effect of in vs. outwards mobility 
*******************************************************************************************************

use "RevisionJEEA\LSYPE_Analysis_Data.dta", replace

*******************************************
*	PREPARING THE MAIN VARIABLES NEEDED   *
*******************************************

tab k2_year, gen(aayy)

*Generating change variables
#delimit ;
local y "OA_k2_total_pc100 OA_fsme OA_efl OA_sen OA_male OA_pop";
#delimit cr;
foreach i of local y {
g d_`i'=`i'_y9 - `i'_y7
sum d_`i', det
}
gen va_k2k3=k3_total_pc100-k2_total_pc100 

***********************
egen sch7_year7=group(schid_y7 )
codebook sch7_year7
egen ps_sch_year=group(k2_schid schid_y7 )
codebook ps_sch_year

*******************************************
*	MORE DESCRIPTIVE STATISTICS; PLASC	*
*******************************************

*Individual characteristics
sum k2_total_pc100 k3_total_pc100 va_k2k3 aayy* fsme male sen /*total_pupils*/

*Central cohort mobility - this is the most relevant
sum  OA_move_out_ext OA_move_in_ext OA_mobility_ext Prim_mobility_ext_2y
corr OA_move_out_ext OA_move_in_ext 
corr OA_mobility_ext Prim_mobility_ext_2y

*More zeros in CC and Primary than if using adjacent cohorts too
sum OA_mobility_ext Prim_mobility_ext_2y, det

***********************
sum OA_k2_total_pc100_y7 OA_k2_total_pc100_y9 OA_fsme_y7 OA_fsme_y9 OA_sen_y7 OA_sen_y9 OA_male_y7 OA_male_y9 OA_pop_y7 OA_pop_y9
sum d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male d_OA_pop

*************************
*Prepare controls for changes in ethnic composition of neighbourhood and population changes		
local z "OA_eth_d1 OA_eth_d2 OA_eth_d3 OA_eth_d4 OA_eth_d5 OA_eth_d6 OA_eth_d7 OA_eth_d8 "
foreach i of local z {
gen d_`i'=`i'_y9-`i'_y7
sum d_`i'
sum d_`i', det
}
		
*Keeping data used for regressions
drop hp*
drop cen*
drop OA02* OA03* OA04*
drop a drop

*******************************************
*	REGRESSION ANALAYSIS	
*******************************************

tab lsype_palhome
gen palhome_rec=lsype_palhome
recode palhome_rec -99=.  -1 1 2 = 0  3 4=1

tab lsype_whofree
gen free_friends=0
replace free_friends=1 if lsype_whofree==2 
replace free_friends=. if lsype_whofree==-99 | lsype_whofree==-1

tab lsype_excpal
gen excl_friend=0
replace excl_friend=1 if lsype_excpal==1 
replace excl_friend=. if lsype_excpal<-1

gen youth_club=.
replace youth_club=1 if lsype_alei1_14==1
replace youth_club=0 if lsype_alei1_14==0

gen mess_in=.
replace mess_in=1 if lsype_alei1_16==1
replace mess_in=0 if lsype_alei1_16==0	

gen combine2=palhome_rec+free_friends-excl_friend+youth_club-mess_in

*Regressions with standard controls and secondary school fixed effects
areg  palhome_rec  OA_mobility_ext aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
areg  free_friends OA_mobility_ext aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
areg  excl_friend  OA_mobility_ext aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
areg  youth_club OA_mobility_ext aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
areg mess_in OA_mobility_ext aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)

egen combine2_std=std(combine2)
egen OA_mobility_ext_std=std(OA_mobility_ext) 
areg combine2_std OA_mobility_ext_std aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
		
*Standard controls, school fixed effects and in vs out mobility (note: drop population change control)
areg  palhome_rec  OA_move_out_ext OA_move_in_ext  aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
lincom OA_move_out_ext-OA_move_in_ext 
testparm OA_move_out_ext OA_move_in_ext
testparm OA_move_out_ext OA_move_in_ext, eq		
areg  free_friends OA_move_out_ext OA_move_in_ext  aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
lincom OA_move_out_ext-OA_move_in_ext 
testparm OA_move_out_ext OA_move_in_ext
testparm OA_move_out_ext OA_move_in_ext, eq				
areg  excl_friend  OA_move_out_ext OA_move_in_ext  aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
lincom OA_move_out_ext-OA_move_in_ext 
testparm OA_move_out_ext OA_move_in_ext
testparm OA_move_out_ext OA_move_in_ext, eq		
areg  youth_club OA_move_out_ext OA_move_in_ext  aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
lincom OA_move_out_ext-OA_move_in_ext 
testparm OA_move_out_ext OA_move_in_ext
testparm OA_move_out_ext OA_move_in_ext, eq				
areg mess_in OA_move_out_ext OA_move_in_ext  aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)
lincom OA_move_out_ext-OA_move_in_ext 	
testparm OA_move_out_ext OA_move_in_ext
testparm OA_move_out_ext OA_move_in_ext, eq		

*Standardized
egen OA_move_out_ext_std=std(OA_move_out_ext)
egen OA_move_in_ext_std=std(OA_move_in_ext)
areg combine2_std OA_move_out_ext_std OA_move_in_ext_std aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		, cluster(OA_y7)  absorb(schid_y7)	
lincom OA_move_out_ext_std-OA_move_in_ext_std 
testparm OA_move_out_ext_std OA_move_in_ext_std
testparm OA_move_out_ext_std OA_move_in_ext_std, eq		
		
*******************
*Additional LSYPE controls and primary by secondary effects
	
sum lsype_accom lsype_sinpar lsype_edump lsype_workmp lsype_nosib lsype_nysib 
replace lsype_nosib=5 if lsype_nosib>5
replace lsype_nysib=5 if lsype_nysib>5

***********************
areg combine2_std OA_mobility_ext_std aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_pop d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		i.lsype_accom lsype_sinpar i.lsype_edump i.lsype_workmp lsype_nosib lsype_nysib ///
		, cluster(OA_y7)  absorb(ps_sch_year)
	
******************
*Separate effects of mobility in and mobility out
areg combine2_std OA_move_out_ext_std OA_move_in_ext_std aayy* fsme male sen eth_d1-eth_d8 ///
		Prim_mobility_ext_2y d_OA_k2_total_pc100 d_OA_fsme d_OA_sen d_OA_male ///
		OA_k2_total_pc100_y7 OA_fsme_y7 OA_sen_y7 OA_male_y7 OA_pop_y7 ///
		d_OA_eth_d1 d_OA_eth_d2 d_OA_eth_d3 d_OA_eth_d4 d_OA_eth_d5 d_OA_eth_d6 d_OA_eth_d7 d_OA_eth_d8 ///
		OA_eth_d1_y7 OA_eth_d2_y7 OA_eth_d3_y7 OA_eth_d4_y7 OA_eth_d5_y7 OA_eth_d6_y7 OA_eth_d7_y7 OA_eth_d8_y7 /// 
		i.lsype_accom lsype_sinpar i.lsype_edump i.lsype_workmp lsype_nosib lsype_nysib ///
		, cluster(OA_y7)  absorb(ps_sch_year)			
lincom OA_move_out_ext_std-OA_move_in_ext_std 
testparm OA_move_out_ext_std OA_move_in_ext_std
testparm OA_move_out_ext_std OA_move_in_ext_std, eq		
	
*******************





