clear 
clear all
capture log close
set mem 3g
set matsize 5000
set maxvar 10000
set more off

cd "F:\Work\OlmoFelix\Mobility\workfiles\"

*log using "F:\Work\OlmoFelix\Mobility\Logfiles\RevisionJEEA\Mobility_Analysis_4cohorts_Jul2015_RevisionJEEA_Version1.log", replace

*******************************************************************************************************
*	EFFECTS OF MOBILITY IN THE NEIGHBOURHOOD - Steve Gibbons, Olmo Silva, Felix Weinhardt
*	This do file uses four cohorts of pupils finishing primary and moving up to the middle of secondary school
*	Note that secondary schools mobility is between year 6 (KS2) and year 9 (KS3)
*******************************************************************************************************

*******************************************************************************************************
*	THHIS VERSION IS FROM JULY 2015. IT TAKES INTO ACCOUNT THE COMMENTS FROM THE EDITOR AND THE REFEREES OF JEEA
*	SOME OF THE ORIGINAL ANALYSIS (CONTAINED IN THE WORKING PAPER) IS DROPPED SINCE IT IS NOT BE REPORTED ANY MORE
*******************************************************************************************************

use "RevisionJEEA\mobility_data_for_analysis_July2015_RevisionJEEA.dta", clear

*******************************************
*	TABLE 1 - SUMMARY STATISTICS
*******************************************

*Individual characteristics
sum k2_total_pc100 k3_total_pc100 va_k2k3 k1_average fsme male sen total_pupils

*Nhood characteristics
sum CCOA_mobility_ext CCOA_move_out_ext CCOA_move_in_ext Pr_OA_mobility_ext_3y 
sum CCOA_k1_average_y6 d_CCOA_k1_average CCOA_fsme_y6 d_CCOA_fsme CCOA_sen_y6 d_CCOA_sen CCOA_male_y6  d_CCOA_male CCOA_pop_y6 d_CCOA_pop

 
*******************************************
*	FIGURE 1 - MOBILITY GRAPHS
*******************************************
 
areg CCOA_mobility_ext, cluster(OA_y6) absorb(OA_y6)
predict res_mob_OA, residual
sum res_mob_OA, det

egen OA_y6_num=group(OA_y6)
capture drop _merge
reghdfe CCOA_mobility_ext , absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num) tol(0.0001) res(res_mob_OA_SY)
reghdfe CCOA_mobility_ext , absorb(OA_y6_num ps_sch_year) vce (cluster OA_y6_num) tol(0.0001) res(res_mob_OA_PSY)

drop OA_y6_num

capture erase a.gph 
capture erase b.gph 
capture erase c.gph 
capture erase d.gph 
capture erase e.gph 
capture erase f.gph 

capture erase mob_final_graph.gph
hist CCOA_mobility_ext , xtitle("N'hood Turnover") fraction saving(a) xlabel(0(0.25)1) 
hist res_mob_OA, xtitle("Dev. from OA effects") fraction saving(d) xlabel(-0.75(0.25)0.75)
hist res_mob_OA_SY, xtitle("Dev. from OA & sec-by-cohort effects") fraction saving(e) xlabel(-0.75(0.25)0.75)
hist res_mob_OA_PSY, xtitle("Dev. from OA & prim-by-sec-by-cohort effects") fraction saving(f) xlabel(-0.75(0.25)0.75)

gr combine a.gph d.gph e.gph f.gph, cols(2) rows(2) saving(mob_final_graph)

sum CCOA_mobility_ext res_mob_OA res_mob_OA_SY res_mob_OA_PSY

*******************************************
*	TABLE 2 - MAIN REGRESSIONS 		
*******************************************

******* Columns (1) and (2)
*Value-added, no unobservables
reg va_k2k3 CCOA_mobility_ext aayy* , cluster(OA_y6) 

reg  va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, cluster(OA_y6) 
		
******* NOT REPORTED (DISCUSSED)
*Value-added, sec school by year FX
areg va_k2k3 CCOA_mobility_ext aayy* , cluster(OA_y6) absorb(sch7_year7)

areg  va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, cluster(OA_y6) absorb(sch7_year7)

******* NOT REPORTED (DISCUSSED)
*Value-added, sec school by primary by year FX
areg va_k2k3 CCOA_mobility_ext aayy* , cluster(OA_y6) absorb(ps_sch_year)

areg  va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, cluster(OA_y6) absorb(ps_sch_year)
		
******* Columns (3) and (4)
*Value-added, N'hood FX
areg va_k2k3 CCOA_mobility_ext aayy* , cluster(OA_y6) absorb(OA_y6)

areg  va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, cluster(OA_y6) absorb(OA_y6)
				
testparm Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6

testparm Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male d_CCOA_pop 
		
******* Columns (5) and (6)
*Value-added, N'hood FX and Secondary by Year FX; note: this uses a different Stata command
egen OA_y6_num=group(OA_y6)
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext aayy* , absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num) tol(0.0001)	

capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num) tol(0.0001)	

******* Columns (7) and (8)
*Value-added, N'hood FX and Secondary by Year FX; separating movers in and movers out
capture drop _merge
reghdfe  va_k2k3 CCOA_move_in_ext CCOA_move_out_ext aayy* /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm CCOA_move_in_ext CCOA_move_out_ext 
testparm CCOA_move_in_ext CCOA_move_out_ext, eq

capture drop _merge
reghdfe  va_k2k3 CCOA_move_in_ext CCOA_move_out_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_pop_y6 CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num ps_sch_year) vce (cluster OA_y6_num ) tol(0.0001)	
testparm CCOA_move_in_ext CCOA_move_out_ext 
testparm CCOA_move_in_ext CCOA_move_out_ext, eq
	
******************************************
* TABLE 3 - INDIVIDUAL-LEVEL BALANCING	
******************************************

xtile k1_average_pc100 = k1_average , n(100)
gen va_k2k1=- k1_average_pc100+ k2_total_pc100

******* School/pupil related variables included in the balancing
local z "va_k2k1 k1_average fsme male sen k1_overall_score_sch_y7 k2_total_pc100_sch_y7 std_dev_k2_y7 total_pupils fsme_k3 fsme_k4 Score_k3_std Score_k4_std open_inst close_inst AC_GCSE_nodrop_tv tot_abs_nodrop_tv"
foreach i of local z{
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "For characteristic `i' and for treatment CCOA_mobility_ext, NO FIXED EFFECTS"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	reg `i' CCOA_mobility_ext aayy* , cluster(OA_y6) 
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "For characteristic `i' and for treatment CCOA_mobility_ext, WITH OA FIXED EFFECTS"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	areg `i' CCOA_mobility_ext aayy* , absorb(OA_y6) cluster(OA_y6) 
  }
  
******* Property market information from land registry
gen det_semi=semi+detach
gen house=semi+detach+terrace
local z "hedonic_p_tv newbuild owntyp flat semi terrace detach det_semi house trans_count"
foreach i of local z{
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "For characteristic `i' and for treatment CCOA_mobility_ext, NO FIXED EFFECTS"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	reg `i' CCOA_mobility_ext aayy* , cluster(OA_y6) 
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	display "For characteristic `i' and for treatment CCOA_mobility_ext, WITH OA FIXED EFFECTS"
	display "%%%%%%%%%%%%%%%%%%%%%%%%%%"
	areg `i' CCOA_mobility_ext aayy* , absorb(OA_y6) cluster(OA_y6) 
  }
 
******* Check house price balancing in areas where there are not too many renters - use Census data to disentngle
sum  cen_tenure_ownd , det

*Split by median 
reg hedonic_p_tv CCOA_mobility_ext aayy* if cen_tenure_ownd>=.7744361, cluster(OA_y6) 
areg hedonic_p_tv CCOA_mobility_ext aayy* if cen_tenure_ownd>=.7744361, absorb(OA_y6) cluster(OA_y6) 

*Split by top 25th Pctile (capture predominantly owned places)
reg hedonic_p_tv CCOA_mobility_ext aayy* if cen_tenure_ownd>=.920354, cluster(OA_y6) 
areg hedonic_p_tv CCOA_mobility_ext aayy* if cen_tenure_ownd>=.920354, absorb(OA_y6) cluster(OA_y6) 
   
******************************************
* TABLE 4 - FALSIFICATION, ROBUSTNESS AND EXTENSIONS
******************************************

******* Column (2) : lagged dependent variable approach no IV 
capture drop _merge
reghdfe k3_total_pc100 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		k2_total_pc100 , absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001) 

******* NOT REPORTED (DISCUSSED)
*IV approach using Teacher Assessment at KS2	
capture drop _merge
reghdfe k3_total_pc100 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		(k2_total_pc100 = k2_ta_average), absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001) 
	
******* Columns (3)
*Value-added, N'hood FX and Primary bY Secondary by Year FX
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num ps_sch_year) vce (cluster OA_y6_num) tol(0.0001)	

******* Column (4) : drop 30% smallest nhoods
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		if CCOA_pop_y9>=4 & CCOA_pop_y6>=4, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
		
******* Column (5) : LSOA nhood aggragates		
*All at the LSOA level - LSOA mob only
egen LSOA_y6_num=group(LSOA_y6)
capture drop _merge
reghdfe va_k2k3 LSOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_LSOA_k1_average d_LSOA_fsme d_LSOA_sen d_LSOA_male ///
		LSOA_k1_average_y6 LSOA_fsme_y6 LSOA_sen_y6 LSOA_male_y6  ///
		d_LSOA_pop LSOA_pop_y6 ///
		d_LSOA_eth_d1 d_LSOA_eth_d2 d_LSOA_eth_d3 d_LSOA_eth_d4 d_LSOA_eth_d5 d_LSOA_eth_d6 d_LSOA_eth_d7 d_LSOA_eth_d8 ///
		LSOA_eth_d1_y6 LSOA_eth_d2_y6 LSOA_eth_d3_y6 LSOA_eth_d4_y6 LSOA_eth_d5_y6 LSOA_eth_d6_y6 LSOA_eth_d7_y6 LSOA_eth_d8_y6 /// 
		, absorb(LSOA_y6_num sch7_year7) vce (cluster LSOA_y6_num) tol(0.0001)	
		
******* Column (6) : ITT estimates are done with a different dataset that includes movers and use a different do file

******************************************
* TABLE 5 - HETEROGENEITY BY PUPIL CHARACTERISTICS
******************************************

gen low_ks1=0
replace low_ks1=1 if k1_average<=15.66
gen hi_ks1=low_ks1
recode hi_ks1 1=0 0=1
tab hi_ks1 low_ks1

gen female = male
recode female 1=0 0=1
tab female male

gen no_sen = sen
recode no_sen 1=0 0=1
tab no_sen sen

gen no_fsme = fsme
recode no_fsme 1=0 0=1
tab no_fsme fsme

local y "hi_ks1 low_ks1 female male no_sen sen no_fsme fsme"
foreach i of local y {
gen `i'_mobility=`i'*CCOA_mobility_ext 
}

******* Columns (1) : High vs. Low Ability (above/below KS1 median)
capture drop _merge
reghdfe va_k2k3 low_ks1_mobility hi_ks1_mobility low_ks1 aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
lincom low_ks1_mobility-hi_ks1_mobility 
testparm low_ks1_mobility hi_ks1_mobility 
testparm low_ks1_mobility hi_ks1_mobility , eq		

******* Columns (2): FSME vs. Non-FSME
capture drop _merge
reghdfe va_k2k3 fsme_mobility no_fsme_mobility aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
lincom fsme_mobility-no_fsme_mobility 		
testparm fsme_mobility no_fsme_mobility
testparm fsme_mobility no_fsme_mobility, eq

******* Columns (3): SEN vs. Non-SEN
capture drop _merge
reghdfe va_k2k3 sen_mobility no_sen_mobility aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
lincom sen_mobility-no_sen_mobility 
testparm sen_mobility no_sen_mobility
testparm sen_mobility no_sen_mobility, eq

******* Columns (4) : Male vs. Female
capture drop _merge
reghdfe va_k2k3 male_mobility female_mobility aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001) 
lincom male_mobility-female_mobility 
testparm male_mobility female_mobility
testparm male_mobility female_mobility, eq

******************************************
* TABLE 7 - HETEROGENEITY BY NHOOD CHARACTERISTICS
******************************************

local z "cen_SH_per cen_lonep cen_qual_4_5 cen_tenure_ownd cen_nonEU_orig cen_density AC_GCSE_nodrop hedonic_p"
foreach i of local z {
sum `i', det
egen med_`i'=median(`i')

gen hi_`i'=1 if `i'>=med_`i'
replace hi_`i'=0 if `i'<med_`i'

gen lo_`i'=hi_`i'
recode lo_`i' 1=0 0=1 .=.
tab hi_`i' lo_`i'

}

local y "hi_cen_SH_per lo_cen_SH_per hi_cen_tenure_ownd lo_cen_tenure_ownd hi_cen_lonep lo_cen_lonep hi_cen_qual_4_5 lo_cen_qual_4_5 hi_cen_nonEU_orig lo_cen_nonEU_orig hi_hedonic_p lo_hedonic_p hi_AC_GCSE_nodrop lo_AC_GCSE_nodrop hi_cen_density lo_cen_density"
foreach i of local y{
	gen mob_`i'=`i'*CCOA_mobility_ext
	sum mob_`i'
	}

local y "cen_SH_per cen_tenure_ownd cen_lonep cen_qual_4_5 cen_nonEU_orig hedonic_p AC_GCSE_nodrop cen_density"
foreach i of local y{
display "This breakdown is for census variable `i'"
capture drop _merge
reghdfe va_k2k3  mob_hi_`i' mob_lo_`i' aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
lincom mob_hi_`i'-mob_lo_`i' 
testparm mob_hi_`i' mob_lo_`i' 
testparm mob_hi_`i' mob_lo_`i' , eq	

}

******* ADDITIONAL RESULTS - NOT REPORTED (SOME ARE DISCUSSED)

*Top 10 cities vs. the rest
gen top_mob=CCOA_mobility_ext*top10city
gen bottom=top10city
recode bottom 0=1 1=0
gen bottom_mob=bottom*CCOA_mobility_ext
capture drop _merge
reghdfe va_k2k3 top_mob bottom_mob aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm  top_mob bottom_mob, eq
testparm  top_mob bottom_mob

*London vs. the rest
gen lon_mob=london*CCOA_mobility_ext
gen no_lon_mob=no_london*CCOA_mobility_ext
capture drop _merge
reghdfe va_k2k3 lon_mob no_lon_mob aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm  lon_mob no_lon_mob, eq
testparm  lon_mob no_lon_mob

*Expanding vs. shrinking n'hoods 
gen d_grow=.
replace d_grow=1 if d_CCOA_pop>=0 & d_CCOA_pop!=.
replace d_grow=0 if d_CCOA_pop<0 & d_CCOA_pop!=.	
gen d_shrink=d_grow
recode d_shrink 0=1 1=0
gen CCOA_mobility_ext_grow=CCOA_mobility_ext*d_grow
gen CCOA_mobility_ext_shrink=CCOA_mobility_ext*d_shrink
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext_grow CCOA_mobility_ext_shrink aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		/*d_CCOA_pop*/ CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm CCOA_mobility_ext_grow CCOA_mobility_ext_shrink 
testparm CCOA_mobility_ext_grow CCOA_mobility_ext_shrink , eq

******************************************
* TABLE 8 - HETEROGENEITY BY SIMILARITY OF STAYERS AND MOVERS
******************************************

******* Columns (1) : same age vs. adults
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext turnover_45_64_d_1 aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
lincom CCOA_mobility_ext-turnover_45_64_d_1
testparm CCOA_mobility_ext turnover_45_64_d_1
testparm CCOA_mobility_ext turnover_45_64_d_1, eq

******* Columns (2) : same age vs. 1year younger
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext  OA_mobility_ext_1yroldyg aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		if OA_mobility_ext_1yrold!=., absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)			
lincom CCOA_mobility_ext -OA_mobility_ext_1yroldyg 		
testparm CCOA_mobility_ext  OA_mobility_ext_1yroldyg 
testparm CCOA_mobility_ext  OA_mobility_ext_1yroldyg , eq

******* Columns (3) : same age vs. 1year older
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext OA_mobility_ext_1yrold  aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		if OA_mobility_ext_1yroldyg!=. , absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)			
lincom CCOA_mobility_ext-OA_mobility_ext_1yrold 		
testparm CCOA_mobility_ext OA_mobility_ext_1yrold  
testparm CCOA_mobility_ext OA_mobility_ext_1yrold  , eq
		
******* Columns (4) : same vs. different ability
*Note that we control for hi_ks1 in specification
gen OA_mobility_k1_worsemed = CCOA_mobility_ext -OA_mobility_k1_bettermed 
gen OA_mobility_same_ability=.
replace OA_mobility_same_ability=OA_mobility_k1_worsemed if hi_ks1==0
replace OA_mobility_same_ability=OA_mobility_k1_bettermed if hi_ks1==1
gen OA_mobility_opp_ability=.
replace OA_mobility_opp_ability=OA_mobility_k1_worsemed if hi_ks1==1
replace OA_mobility_opp_ability=OA_mobility_k1_bettermed if hi_ks1==0
capture drop _merge
reghdfe va_k2k3 OA_mobility_same_ability OA_mobility_opp_ability ///
		aayy* k1_average hi_ks1 fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
lincom OA_mobility_same_ability-OA_mobility_opp_ability  
testparm OA_mobility_same_ability OA_mobility_opp_ability  
testparm OA_mobility_same_ability OA_mobility_opp_ability , eq

******* Columns (5) : same vs. different gender
gen OA_mobility_female = CCOA_mobility_ext -OA_mobility_male 
gen OA_mobility_same_gen=.
replace OA_mobility_same_gen=OA_mobility_male if male==1
replace OA_mobility_same_gen=OA_mobility_female if male==0
gen OA_mobility_opp_gen=.
replace OA_mobility_opp_gen=OA_mobility_male if male==0
replace OA_mobility_opp_gen=OA_mobility_female if male==1

capture drop _merge
reghdfe va_k2k3 OA_mobility_opp_gen OA_mobility_same_gen ///
		aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
lincom OA_mobility_opp_gen-OA_mobility_same_gen 
testparm OA_mobility_opp_gen OA_mobility_same_gen   
testparm OA_mobility_opp_gen OA_mobility_same_gen , eq

******* Columns (6) : same vs. adjacent n'hoods (output areas)
capture drop _merge
reghdfe va_k2k3 CCOA_mobility_ext OUT_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
lincom CCOA_mobility_ext-OUT_mobility_ext
testparm CCOA_mobility_ext OUT_mobility_ext
testparm CCOA_mobility_ext OUT_mobility_ext, eq

******* Columns (7) : same vs. adjacent n'hoods (output areas)
*Note: this is done for the subset of pupils who do not change school between year 7 and year 9
capture drop _merge
reghdfe va_k2k3 OA_mobility_schid_ext OA_mobility_diffschid_ext aayy* k1_average fsme male sen  eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 ///
		if diff_school==0, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm  OA_mobility_schid_ext OA_mobility_diffschid_ext, eq
testparm  OA_mobility_schid_ext OA_mobility_diffschid_ext
			
******* ADDITIONAL RESULTS - NOT REPORTED (SOME ARE DISCUSSED)

*ROBUSTNESS TO PUPILS NOT CHANGING SCHOOLS BETWEEN YEAR 7 AND YEAR 9
capture drop _merge
reghdfe  va_k2k3 CCOA_mobility_ext aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		if diff_school==0, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
	
*SEPARATE MOBILITY OVER THE THREE MOVES BETWEEN KS2 AND KS3
sum CCOA_mobility_ext OA_mobility_y7 OA_mobility_y8 OA_mobility_y9
corr CCOA_mobility_ext OA_mobility_y7 OA_mobility_y8 OA_mobility_y9
capture drop _merge
reghdfe va_k2k3 OA_mobility_y7 OA_mobility_y8 OA_mobility_y9 aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm OA_mobility_y7 OA_mobility_y8 OA_mobility_y9 
testparm OA_mobility_y7 OA_mobility_y8 OA_mobility_y9 , eq

*HETEROGENEOUS EFFECTS FOR PUPILS IN AREAS WITH MORE/LESS SCHOOLS AVAILABLE TO CHOOSE FROM
sum sch_count, det
gen hi_sch=0
replace hi_sch=1 if sch_count>=3
gen lo_sch=0
replace lo_sch=1 if sch_count<3
tab hi_sch lo_sch

gen mob_hi_sch=hi_sch*CCOA_mobility_ext
gen mob_lo_sch=lo_sch*CCOA_mobility_ext
capture drop _merge
reghdfe va_k2k3 mob_hi_sch mob_lo_sch aayy* k1_average fsme male sen  eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 ///
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
lincom mob_hi_sch-mob_lo_sch 
testparm mob_hi_sch mob_lo_sch, eq
testparm mob_hi_sch mob_lo_sch
		
******************************************
* APPENDIX TABLE 1 - HETEROGENEITY BY MOVERS' TYPES - MALE/FEMALE, HI/LOW ABILITY
******************************************	

sum OA_mobility_male OA_mobility_k1_bettermed CCOA_mobility_ext
corr CCOA_mobility_ext OA_mobility_male OA_mobility_k1_bettermed 

******* Column (1) : high ability male vs. low ability mobility 
capture drop _merge
reghdfe va_k2k3 OA_mobility_k1_worsemed OA_mobility_k1_bettermed ///
		aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)
testparm OA_mobility_k1_worsemed OA_mobility_k1_bettermed 
testparm OA_mobility_k1_worsemed OA_mobility_k1_bettermed , eq

******* Column (2a) and (2b) : high ability male vs. low ability mobility for high/low ability stayers
local y "hi_ks1 low_ks1 "
foreach i of local y {
gen `i'_mobility_worse=`i'*OA_mobility_k1_worsemed 
gen `i'_mobility_better=`i'*OA_mobility_k1_bettermed
}
capture drop _merge
reghdfe va_k2k3 hi_ks1_mobility_worse hi_ks1_mobility_better low_ks1_mobility_worse low_ks1_mobility_better ///
		aayy* k1_average low_ks1 fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001) 
testparm hi_ks1_mobility_worse hi_ks1_mobility_better 
testparm hi_ks1_mobility_worse hi_ks1_mobility_better , eq
testparm low_ks1_mobility_worse low_ks1_mobility_better  
testparm low_ks1_mobility_worse low_ks1_mobility_better , eq
testparm hi_ks1_mobility_worse hi_ks1_mobility_better low_ks1_mobility_worse low_ks1_mobility_better  
testparm hi_ks1_mobility_worse hi_ks1_mobility_better low_ks1_mobility_worse low_ks1_mobility_better , eq

******* Column (3) : male vs. female mobility
capture drop _merge
reghdfe va_k2k3 OA_mobility_female OA_mobility_male ///
		aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	 
testparm OA_mobility_female OA_mobility_male 
testparm OA_mobility_female OA_mobility_male , eq

******* Column (4a) and (4b) : male vs. female mobility for male and female stayers
local y "female male "
foreach i of local y {
gen `i'_mobility_fem=`i'*OA_mobility_female 
gen `i'_mobility_male=`i'*OA_mobility_male 
}
capture drop _merge
reghdfe va_k2k3  female_mobility_fem female_mobility_male male_mobility_fem male_mobility_male ///
		aayy* k1_average fsme male sen eth_d1-eth_d8 ///
		total_pupils sd_* ///
		Pr_OA_mobility_ext_3y  d_CCOA_k1_average d_CCOA_fsme d_CCOA_sen d_CCOA_male ///
		CCOA_k1_average_y6 CCOA_fsme_y6 CCOA_sen_y6 CCOA_male_y6  ///
		d_CCOA_pop CCOA_pop_y6 ///
		d_CCOA_eth_d1 d_CCOA_eth_d2 d_CCOA_eth_d3 d_CCOA_eth_d4 d_CCOA_eth_d5 d_CCOA_eth_d6 d_CCOA_eth_d7 d_CCOA_eth_d8 ///
		CCOA_eth_d1_y6 CCOA_eth_d2_y6 CCOA_eth_d3_y6 CCOA_eth_d4_y6 CCOA_eth_d5_y6 CCOA_eth_d6_y6 CCOA_eth_d7_y6 CCOA_eth_d8_y6 /// 		
		, absorb(OA_y6_num sch7_year7) vce (cluster OA_y6_num ) tol(0.0001)	
testparm female_mobility_fem female_mobility_male 
testparm female_mobility_fem female_mobility_male , eq
testparm male_mobility_fem male_mobility_male
testparm male_mobility_fem male_mobility_male, eq
testparm female_mobility_fem female_mobility_male male_mobility_fem male_mobility_male
testparm female_mobility_fem female_mobility_male male_mobility_fem male_mobility_male, eq


